import React, { useState, useEffect } from 'react';
import { BrowserRouter as Router, Route, Switch } from 'react-router-dom';
import { onAuthStateChanged, signOut } from 'firebase/auth';
import { initializeApp } from 'firebase/app';
import { getAuth } from 'firebase/auth';
import AuthForm from './components/AuthForm';
import Home from './pages/Home';
import Register from './pages/Register';
import Login from './pages/Login';
import UserProfile from './pages/UserProfile';
import Header from './components/Header';
import Footer from './components/Footer';

// Firebase configuration
const firebaseConfig = {
  apiKey: "AIzaSyBKk0POvwirX9vE69Ir-7jiBZcsnNnPU6k",
  authDomain: "cryptobicon-5bb2d.firebaseapp.com",
  projectId: "cryptobicon-5bb2d",
  storageBucket: "cryptobicon-5bb2d.firebasestorage.app",
  messagingSenderId: "296480444835",
  appId: "1:296480444835:web:df3e8276a80350023c0a16",
  measurementId: "G-TH9DEK0DQL"
};

// Initialize Firebase
const app = initializeApp(firebaseConfig);
const auth = getAuth(app);

const App = () => {
  const [user, setUser] = useState(null);  // Track user authentication state
  const [error, setError] = useState(null);  // Handle errors if any

  // Track authentication state (when the user logs in or out)
  useEffect(() => {
    const unsubscribe = onAuthStateChanged(auth, (user) => {
      setUser(user);  // Update the user state when the authentication state changes
    });

    // Cleanup subscription when the component is unmounted
    return () => unsubscribe();
  }, []);

  // Handle logout functionality
  const handleLogout = async () => {
    try {
      await signOut(auth);  // Firebase sign out
      alert('User logged out successfully!');
    } catch (error) {
      setError(error.message);  // Handle error during logout
    }
  };

  return (
    <Router>
      <Header user={user} handleLogout={handleLogout} />
      <div>
        <h1>Welcome to Cryptobicon</h1>

        {/* Show error message if any */}
        {error && <p style={{ color: 'red' }}>{error}</p>}

        {/* If user is logged in, show their email and logout button */}
        {user ? (
          <div>
            <h2>Welcome, {user.email}</h2>
            <button onClick={handleLogout}>Logout</button>
          </div>
        ) : (
          // If no user, show the AuthForm component for registration/login
          <AuthForm setError={setError} />
        )}
      </div>
      <Switch>
        <Route exact path="/" component={Home} />
        <Route path="/register" component={Register} />
        <Route path="/login" component={Login} />
        <Route path="/profile" component={UserProfile} />
      </Switch>
      <Footer />
    </Router>
  );
};

export default App;