import React, { useState, useEffect } from 'react';
import axios from 'axios';

const TradeHistory = ({ userId }) => {
  const [trades, setTrades] = useState([]);

  useEffect(() => {
    // Fetch trade history data from the backend
    axios.get(`/api/market/trades/${userId}`)
      .then(response => {
        setTrades(response.data);
      })
      .catch(error => {
        console.error('Error fetching trade history data:', error);
      });
  }, [userId]);

  return (
    <div>
      <h2>Trade History</h2>
      <table>
        <thead>
          <tr>
            <th>Date</th>
            <th>Action</th>
            <th>Amount</th>
            <th>Price</th>
            <th>Total</th>
          </tr>
        </thead>
        <tbody>
          {trades.map((trade, index) => (
            <tr key={index}>
              <td>{new Date(trade.timestamp).toLocaleString()}</td>
              <td>{trade.action}</td>
              <td>{trade.amount}</td>
              <td>{trade.price}</td>
              <td>{(trade.amount * trade.price).toFixed(2)}</td>
            </tr>
          ))}
        </tbody>
      </table>
    </div>
  );
};

export default TradeHistory;