import axios from 'axios';

// Create an Axios instance with default settings
const api = axios.create({
  baseURL: 'http://localhost:5000/api',
  headers: {
    'Content-Type': 'application/json',
  },
});

// Function to register a new user
export const registerUser = async (email, password) => {
  try {
    const response = await api.post('/auth/register', { email, password });
    return response.data;
  } catch (error) {
    handleApiError(error);
  }
};

// Function to log in a user
export const loginUser = async (email, password) => {
  try {
    const response = await api.post('/auth/login', { email, password });
    return response.data;
  } catch (error) {
    handleApiError(error);
  }
};

// Function to fetch user data
export const fetchUserData = async (userId) => {
  try {
    const response = await api.get(`/user/${userId}`);
    return response.data;
  } catch (error) {
    handleApiError(error);
  }
};

// Function to fetch order book data
export const fetchOrderBook = async () => {
  try {
    const response = await api.get('/market/orderbook');
    return response.data;
  } catch (error) {
    handleApiError(error);
  }
};

// Function to fetch trade history for a user
export const fetchTradeHistory = async (userId) => {
  try {
    const response = await api.get(`/market/trades/${userId}`);
    return response.data;
  } catch (error) {
    handleApiError(error);
  }
};

// Function to make a trade
export const makeTrade = async (tradeData) => {
  try {
    const response = await api.post('/market/trade', tradeData);
    return response.data;
  } catch (error) {
    handleApiError(error);
  }
};

// Helper function to handle API errors
const handleApiError = (error) => {
  if (error.response && error.response.data) {
    throw error.response.data;
  } else {
    throw new Error('An unexpected error occurred');
  }
};